%define anolis_release 1

Name: nghttp2
Version: 1.51.0
Release: %{anolis_release}%{?dist}
License: MIT
Summary: Experimental HTTP/2 client, server and proxy
URL: https://nghttp2.org/
Source0: https://github.com/tatsuhiro-t/nghttp2/releases/download/v%{version}/nghttp2-%{version}.tar.xz

BuildRequires: CUnit-devel
BuildRequires: c-ares-devel
BuildRequires: gcc-c++
BuildRequires: libev-devel
BuildRequires: libxml2-devel
BuildRequires: make
BuildRequires: openssl-devel
BuildRequires: python3-devel
BuildRequires: systemd-devel
BuildRequires: zlib-devel
BuildRequires: systemd

Requires: libnghttp2 = %{version}-%{release}
%{?systemd_requires}

%description
This package contains the HTTP/2 client, server and proxy programs.


%package -n libnghttp2
Summary: A library implementing the HTTP/2 protocol

%description -n libnghttp2
libnghttp2 is a library implementing the Hypertext Transfer Protocol
version 2 (HTTP/2) protocol in C.


%package -n libnghttp2-devel
Summary: Files needed for building applications with libnghttp2
Requires: libnghttp2 = %{version}-%{release}
Requires: pkgconfig

%description -n libnghttp2-devel
The libnghttp2-devel package includes libraries and header files needed
for building applications with libnghttp2.

%package doc
Summary: Doc files for %{name}
Requires: %{name} = %{EVR}
BuildArch: noarch

%description doc
The %{name}-doc package contains documentation files for %{name}

%prep
%setup -q

# make fetch-ocsp-response use Python 3
sed -e '1 s|^#!/.*python|&3|' -i script/fetch-ocsp-response

%build
%configure PYTHON=%{__python3}              \
    --disable-hpack-tools                   \
    --disable-python-bindings               \
    --disable-static                        \
    --with-libxml2                          \
    --without-spdylay

# avoid using rpath
sed -i libtool                              \
    -e 's/^runpath_var=.*/runpath_var=/'    \
    -e 's/^hardcode_libdir_flag_spec=".*"$/hardcode_libdir_flag_spec=""/'

%make_build


%install
%make_install
install -D -m0444 -p contrib/nghttpx.service \
    "$RPM_BUILD_ROOT%{_unitdir}/nghttpx.service"

# not needed on Fedora/RHEL
rm -f "$RPM_BUILD_ROOT%{_libdir}/libnghttp2.la"

# will be installed via %%doc
rm -f "$RPM_BUILD_ROOT%{_datadir}/doc/nghttp2/README.rst"

%generate_compatibility_deps

%ldconfig_scriptlets -n libnghttp2

%post
%systemd_post nghttpx.service

%postun
%systemd_postun nghttpx.service


%check
# test the just built library instead of the system one, without using rpath
export "LD_LIBRARY_PATH=$RPM_BUILD_ROOT%{_libdir}:$LD_LIBRARY_PATH"
%make_build check


%files
%{_bindir}/h2load
%{_bindir}/nghttp
%{_bindir}/nghttpd
%{_bindir}/nghttpx
%{abidir}/h2load-option.list
%{abidir}/nghttp-option.list
%{abidir}/nghttpd-option.list
%{abidir}/nghttpx-option.list
%{_datadir}/nghttp2
%{_mandir}/man1/h2load.1*
%{_mandir}/man1/nghttp.1*
%{_mandir}/man1/nghttpd.1*
%{_mandir}/man1/nghttpx.1*
%{_unitdir}/nghttpx.service

%files -n libnghttp2
%dir %{abidir}
%{_libdir}/libnghttp2.so.*
%{abidir}/libnghttp2*.dump
%{!?_licensedir:%global license %%doc}
%license COPYING

%files -n libnghttp2-devel
%{_includedir}/nghttp2
%{_libdir}/pkgconfig/libnghttp2.pc
%{_libdir}/libnghttp2.so

%files doc
%doc AUTHORS ChangeLog NEWS README README.rst

%changelog
* Wed Feb 08 2023 Xuchun Shang <xuchun.shang@linux.alibaba.com> - 1.51.0-1
- update to version 1.51.0

* Mon Oct 24 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 1.49.0-2
- optimise spec file

* Mon Sep 5 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 1.49.0-1
- update to 1.49.0

* Thu Mar 10 2022 DengXiewei <dengxiewei@linux.alibaba.com> - 1.46.0-1
- Init from upstream 1.46.0
